unit FPImage;

interface

uses
  Windows, SysUtils, Classes, Controls, Forms, Dialogs, ExtCtrls, Menus, 
  IniFiles, jpeg, ExtActns;

type
  TFPImageForm                      = class(TForm)
    Image                           : TImage;
    PopMenu                         : TPopupMenu;
    SaveDialog                      : TSaveDialog;
    LoadDialog                      : TOpenDialog;
    procedure FormCreate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ConvertFileClick(Sender: TObject);
    procedure CopyPicture(Sender: TObject);
    procedure SaveJPGClick(Sender: TObject);
    procedure SaveBMPClick(Sender: TObject);
    procedure SavePNGClick(Sender: TObject);
    procedure FormMouseWheelDown(Sender: TObject; Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
    procedure FormMouseWheelUp(Sender: TObject; Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
    procedure CloseClick(Sender: TObject);
  end;

var
  FPImageForm                       : TFPImageForm;

implementation

{$R *.dfm}

uses Setup, StrUtils, Clipbrd, konvpng;

procedure TFPImageForm.FormCreate(Sender: TObject);
var NewItem               : TMenuItem;
begin
  Caption := 'Bildfenster';

  ImageList := TList.Create;
  ImageList.Add(FPImageForm.Image);

  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := 'convert from file';
  NewItem.OnClick := ConvertFileClick;
  PopMenu.Items.Add(NewItem);

  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := 'copy picture';
  NewItem.OnClick := CopyPicture;
  PopMenu.Items.Add(NewItem);

  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := 'save JPG';
  NewItem.OnClick := SaveJPGClick;
  PopMenu.Items.Add(NewItem);

  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := 'save BMP';
  NewItem.OnClick := SaveBMPClick;
  PopMenu.Items.Add(NewItem);

  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := 'save PNG';
  NewItem.OnClick := SavePNGClick;
  PopMenu.Items.Add(NewItem);

  NewItem := TMenuItem.Create(Self);
  NewItem.Caption := 'close';
  NewItem.OnClick := CloseClick;
  PopMenu.Items.Add(NewItem);

  FPImageForm.Image.Left  := 0;
  FPImageForm.Image.Top   := 0;
  Image.PopupMenu         := PopMenu;

  VertScrollBar.Tracking  := True;
  HorzScrollBar.Tracking  := True;

  MemSetFile := TMemIniFile.Create(SetupFileName);
  try
    Left := MemSetFile.ReadInteger(ProgSetup, WinImageLeft, 350);
    Top := MemSetFile.ReadInteger(ProgSetup, WinImageTop, 50);
    Width := MemSetFile.ReadInteger(ProgSetup, WinImageWidth, 300);
    Height := MemSetFile.ReadInteger(ProgSetup, WinImageHeight, 400);
  finally
    MemSetFile.Free;
  end;
end;

procedure TFPImageForm.FormActivate(Sender: TObject);
var   i                   : Integer;
      Im                  : TImage;
begin
  ClientWidth := Image.Width;
  ClientHeight := Image.Height;
  if Assigned(ImageList) then
    for i := 0 to ImageList.Count - 1 do begin
      Im := ImageList.Items[i];
      Im.PopupMenu := PopMenu;
    end;
end;

procedure TFPImageForm.FormDestroy(Sender: TObject);
begin
  ImageList.Free;
end;

procedure TFPImageForm.ConvertFileClick(Sender: TObject);
var   FileText            : TStringList;
begin
  if LoadDialog.Execute then begin
    FPImageForm.Image.Picture := nil; // clear / lschen
    FPImageForm.Image.Width   := ClientWidth;
    FPImageForm.Image.Height  := ClientHeight;
    // insert here the interface to transport clear text to NSA
    FileText := TStringList.Create;
    try
      FileText.LoadFromFile(LoadDialog.FileName);
      TextAusg(FileText.Text, FPImageForm.Image, FPImageForm, False);
    finally
      FileText.Free;
    end;
    FPImageForm.Show;
  end;
end;

procedure TFPImageForm.CopyPicture(Sender: TObject);
var   Im                  : TImage;
begin
  Im :=     PopMenu.PopupComponent as TImage;
  if Assigned(Im) then Clipboard.Assign(Im.Picture.Bitmap);
end;

procedure TFPImageForm.SaveJPGClick(Sender: TObject);
var   i                   : Integer;
      Im                  : TImage;
      lName               : TFileName;
      pt                  : Integer;
      jp                  : TJPEGImage;
begin
  if SaveDialog.Execute then begin
    pt := Pos('.', SaveDialog.FileName);
    if pt = 0 then pt := Length(SaveDialog.FileName) + 1;
    lName := Copy(SaveDialog.FileName, 1, pt - 1);
    jp := TJPEGImage.Create;
    try
      for i := 0 to ImageList.Count - 1 do begin
        Im := ImageList.Items[i];
        jp.Assign(Im.Picture.Bitmap);
        if ImageList.Count > 1
          then jp.SaveToFile(lName + IntToStr(11 + i) + '.jpg')
          else jp.SaveToFile(lName + '.jpg')
      end;
    finally
      jp.Free;
    end;
  end;
end;

procedure TFPImageForm.SaveBMPClick(Sender: TObject);
var   i                   : Integer;
      Im                  : TImage;
      lName               : TFileName;
      pt                  : Integer;
begin
  if SaveDialog.Execute then begin
    pt := Pos('.', SaveDialog.FileName);
    if pt = 0 then pt := Length(SaveDialog.FileName) + 1;
    lName := Copy(SaveDialog.FileName, 1, pt - 1);
    for i := 0 to ImageList.Count - 1 do begin
      Im := ImageList.Items[i];
      if ImageList.Count > 1
        then Im.Picture.Bitmap.SaveToFile(lName + IntToStr(11 + i) + '.bmp')
        else Im.Picture.Bitmap.SaveToFile(lName + '.bmp');
    end;
  end;
end;

procedure TFPImageForm.SavePNGClick(Sender: TObject);
var   i, pt                     : Integer;
      Im                        : TImage;
      lName                     : TFileName;
      AppliHomePath, s, ext     : string;
begin
  AppliHomePath := ExtractFilePath(Application.ExeName);
  if SaveDialog.Execute then
  begin
    pt := Pos('.', SaveDialog.FileName);
    if pt = 0 then pt := Length(SaveDialog.FileName) + 1;
    lName := Copy(SaveDialog.FileName, 1, pt - 1);
    for i := 0 to ImageList.Count - 1 do
    begin
      Im := ImageList.Items[i];
      if ImageList.Count > 1 then ext := IntToStr(11 + i) else ext := '';
      s := SaveDialog.FileName + ext; // + '.bmp';
      Im.Picture.Bitmap.SaveToFile(s + '.bmp');
      konvpng.KonvertPng(s + '.bmp', s + '.png');
    end;
  end
end;

procedure TFPImageForm.FormMouseWheelDown(Sender: TObject; Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
begin
  VertScrollBar.Position := VertScrollBar.Position + 30;
end;

procedure TFPImageForm.FormMouseWheelUp(Sender: TObject; Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
begin
  VertScrollBar.Position := VertScrollBar.Position - 30;
end;

procedure TFPImageForm.CloseClick(Sender: TObject);
begin
  Close;
end;

end.


