unit FPSetup;

interface

uses
  Classes, Controls, Forms, Dialogs, StdCtrls, ComCtrls, ExtCtrls, Menus, 
  IniFiles, SysUtils, Graphics;

type
  TFPSetupForm                      = class(TForm)
    FontDialog1                     : TFontDialog;
    ColorDialog1                    : TColorDialog;
    Panel                           : TPanel;
    LabFont                         : TLabel;
    TrBarX                          : TTrackBar;
    TrBarY                          : TTrackBar;
    TrackBarRausch                  : TTrackBar;
    BtnHintergrund                  : TButton;
    BtnFontColor                    : TButton;
    BtnConvert                      : TButton;
    LabHorizonal                    : TLabel;
    LabVertikal                     : TLabel;
    LabRauschen                     : TLabel;
    MainMenu1                       : TMainMenu;
    Datei1                          : TMenuItem;
    saveSetupAs                     : TMenuItem;
    SaveLoadDelete                  : TMenuItem;
    close1                          : TMenuItem;
    changeFont1                     : TMenuItem;
    colorbackground1                : TMenuItem;
    colorfont1                      : TMenuItem;
    convert1                        : TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure LabFontClick(Sender: TObject);
    procedure BtnHintergrundClick(Sender: TObject);
    procedure BtnFontColorClick(Sender: TObject);
    procedure BtnConvertClick(Sender: TObject);
    procedure TrBarXChange(Sender: TObject);
    procedure TrBarYChange(Sender: TObject);
    procedure TrackBarRauschChange(Sender: TObject);
    procedure SaveProgSetupClick(Sender: TObject);
    procedure SaveLoadDeleteClick(Sender: TObject);
    procedure CloseClick(Sender: TObject);
  end;

var
  FPSetupForm                       : TFPSetupForm;

implementation

{$R *.dfm}

uses FP, FPImage, FPSaveLoad, Setup;

function ShowFont(Fnt : TFont) : string;
var   stg       : string;
begin
  stg := ' ';
  if fsBold in Fnt.Style then stg := stg + 'bold ';
  if fsItalic in Fnt.Style then stg := stg + 'italic ';
  if fsUnderline in Fnt.Style then stg := stg + 'underline ';
  if fsStrikeOut in Fnt.Style then stg := stg + 'strikeout';
  Result := Fnt.Name + ' ' + IntToStr(Fnt.Size) + stg;
end;

procedure TFPSetupForm.FormCreate(Sender: TObject);
begin
  Caption := 'Fenster Einstellungen';
  AutoSize := True;
  //BorderStyle := bsDialog;

  LabFont.AutoSize := False;
  LabFont.Left := 1;
  LabFont.Width := LabFont.Parent.Width - 2;
  LabFont.Top := 12;
  LabFont.Height := 60;
  LabFont.Color := spBGColor;
  LabFont.Alignment := taCenter;
  LabFont.Hint := 'click to change Font';
  LabFont.ShowHint := True;

  TrackBarRausch.Max := cTrBarRauschMax;

  LabFont.OnClick := LabFontClick;
  TrBarX.OnChange := TrBarXChange;
  TrBarY.OnChange := TrBarYChange;
  TrackBarRausch.OnChange := TrackBarRauschChange;
  BtnConvert.OnClick := BtnConvertClick;
  BtnHintergrund.OnClick := BtnHintergrundClick;
  BtnFontColor.OnClick := BtnFontColorClick;
  saveSetupAs.OnClick := SaveProgSetupClick;
  SaveLoadDelete.OnClick := SaveLoadDeleteClick;
  close1.OnClick := CloseClick;
  changeFont1.OnClick := LabFontClick;
  colorbackground1.OnClick := BtnHintergrundClick;
  colorfont1.OnClick := BtnFontColorClick;
  convert1.OnClick := BtnConvertClick;

  MemSetFile := TMemIniFile.Create(SetupFileName);
  try
    Left := MemSetFile.ReadInteger(ProgSetup, WinSetupLeft, 150);
    Top := MemSetFile.ReadInteger(ProgSetup, WinSetupTop, 250);
  finally
    MemSetFile.Free;
  end;

  try
    ColorDialog1.CustomColors.LoadFromFile('Menuefarben.txt');
  except end;
end;

procedure TFPSetupForm.FormActivate(Sender: TObject);
begin
  LabFont.Color := spBGColor;
  LabFont.Font := spFont;
  LabFont.Font.Color := spFont.Color;
  LabFont.Caption := ShowFont(spFont);
  TrBarX.Position := spHoVar;
  TrBarY.Position := spVeVar;
  TrackBarRausch.Position := spRausch;
end;

procedure TFPSetupForm.BtnConvertClick(Sender: TObject);
begin
  FPForm.ConvertClick(Self);
end;

procedure TFPSetupForm.LabFontClick(Sender: TObject);
begin
  FontDialog1.Font := spFont;
  if FontDialog1.Execute then begin
    LabFont.Font := FontDialog1.Font;
    Setup.spFont := FontDialog1.Font;
    LabFont.Caption := ShowFont(spFont);
    FPForm.Memo.Font := FontDialog1.Font;
    Setup.spFont.Color := FontDialog1.Font.Color;
  end;
end;

procedure TFPSetupForm.BtnHintergrundClick(Sender: TObject);
begin
  ColorDialog1.Color := spBgColor;
  if ColorDialog1.Execute then begin
    Setup.spBgColor := ColorDialog1.Color;
    LabFont.Color := Setup.spBgColor;
    FPForm.Memo.Color := Setup.spBgColor;
    ColorDialog1.CustomColors.SaveToFile('Menuefarben.txt');
  end;
end;

procedure TFPSetupForm.BtnFontColorClick(Sender: TObject);
begin
  ColorDialog1.Color := spFont.Color;
  ColorDialog1.Color := spFont.Color;
  if ColorDialog1.Execute then begin
    LabFont.Font.Color := ColorDialog1.Color;
    Setup.spFont.Color := ColorDialog1.Color;
    FPForm.Memo.Font.Color := ColorDialog1.Color;
    ColorDialog1.CustomColors.SaveToFile('Menuefarben.txt');
  end;
end;

procedure TFPSetupForm.TrBarXChange(Sender: TObject);
begin
  Setup.spHoVar := TrBarX.Position;
end;

procedure TFPSetupForm.TrBarYChange(Sender: TObject);
begin
  Setup.spVeVar := TrBarY.Position;
end;

procedure TFPSetupForm.TrackBarRauschChange(Sender: TObject);
begin
  spRausch := TrackBarRausch.Position;
end;

procedure TFPSetupForm.SaveProgSetupClick(Sender: TObject);
begin
  MemSetFile := TMemIniFile.Create(SetupFileName);
  try
    with FPForm do begin
      MemSetFile.WriteInteger(ProgSetup, WinEditLeft, Left);
      MemSetFile.WriteInteger(ProgSetup, WinEditTop, Top);
      MemSetFile.WriteInteger(ProgSetup, WinEditWidth, Width);
      MemSetFile.WriteInteger(ProgSetup, WinEditHeight, Height);
    end;
    with FPImageForm do begin
      MemSetFile.WriteInteger(ProgSetup, WinImageLeft, Left);
      MemSetFile.WriteInteger(ProgSetup, WinImageTop, Top);
      MemSetFile.WriteInteger(ProgSetup, WinImageWidth, Width);
      MemSetFile.WriteInteger(ProgSetup, WinImageHeight, Height);
    end;
    with FPSetupForm do begin
      MemSetFile.WriteInteger(ProgSetup, WinSetupLeft, Left);
      MemSetFile.WriteInteger(ProgSetup, WinSetupTop, Top);
    end;
    MemSetFile.UpdateFile;
  finally
    MemSetFile.Free;
  end;
  SetSave(StandardSetup);
end;

procedure TFPSetupForm.SaveLoadDeleteClick(Sender: TObject);
begin
  FPSaveLoadForm.ComboBox.Text := ShowFont(spFont);
  FPSaveLoadForm.Show;
end;

procedure TFPSetupForm.CloseClick(Sender: TObject);
begin
  Close;
end;

end.


